;; -*- mode: guix-scheme -*-
;; This "home-environment" file can be passed to 'guix home reconfigure'
;; to reproduce the content of your profile.  This is "symbolic": it only
;; specifies package names.  To reproduce the exact same profile, you also
;; need to capture the channels being used, as returned by "guix describe".
;; See the "Replicating Guix" section in the manual.

(use-modules
 (gnu packages)
 (gnu packages gnupg)
 (gnu packages linux)
 (gnu packages shellutils)
 (nongnu packages game-client)
 (gnu services)
 (guix gexp)
 (guix channels)
 (gnu home)
 (gnu home services)
 (gnu home services desktop)
 (gnu home services gnupg)
 (gnu home services guix)
 (gnu home services mail)
 (gnu home services mcron)
 (gnu home services pm)
 (gnu home services shells)
 (gnu home services shepherd)
 (gnu home services sound)
 (gnu home services ssh)
 (gnu home services syncthing))

(home-environment
 ;; Below is the list of Home services.  To search for available
 ;; services, run 'guix home search KEYWORD' in a terminal.
 (
services
(list
 (service home-shepherd-service-type)
 (service home-msmtp-service-type
          (home-msmtp-configuration
           (default-account "LMail")
           (accounts
            (list
             (msmtp-account
              (name "LMail")
              (configuration
               (msmtp-configuration
                (host "lyrion.ch")
                (port 465)
                (auth? #t)
                (tls? #t)
                (tls-starttls? #f)
                (user "dziltener")
                (from "dziltener@lyrion.ch")
                (password-eval "pass Privat/Mailaccount | head -n 1"))))
             (msmtp-account
              (name "Red Sky")
              (configuration
               (msmtp-configuration
                (host "gmail.com")
                (port 587)
                (auth? #t)
                (tls? #t)
                (tls-starttls? #f)
                (user "dz@redsky.io")
                (from "dziltener@lyrion.ch")
                (password-eval "pass Privat/RedSkyGMail"))))))))
 (simple-service 'ziltis-environment-variable-service
                 home-environment-variables-service-type
                 `(("PATH"               . "$PATH:~/.local/bin")
                   ("PASSWORD_STORE_DIR" . "$XDG_DATA_HOME/password-store")
                   ("XDG_DATA_DIRS" . "$XDG_DATA_DIRS:$XDG_DATA_HOME/flatpak/exports/share")
                   ("XDG_CURRENT_DESKTOP" . "sway")
                   ("RTC_USE_PIPEWIRE"   . "true")
                   ("SSH_ASKPASS"        . "ksshaskpass")
                   ("ELM_DISPLAY"        . "wl")
                   ("SDL_VIDEODRIVER"    . "wayland")
                   ("MOZ_ENABLE_WAYLAND" . "1")
                   ("SSL_CERT_FILE"      . "$HOME/.guix-profile/etc/ssl/certs/ca-certificates.crt")
                   ("CHICKEN_DOC_REPOSITORY"     . "$XDG_DATA_HOME/chicken/doc")
                   ;; ("CHICKEN_INSTALL_REPOSITORY" . "$XDG_DATA_HOME/chicken/eggs")
                   ;; ("CHICKEN_REPOSITORY_PATH"    . "$HOME/.guix-home/profile/var/lib/chicken/11/:$XDG_DATA_HOME/chicken/eggs")
                   ;; ("CHICKEN_INSTALL_PREFIX"     . "$HOME/.local")
                   ("XCURSOR_SIZE"       . "48")
                   ))
 (simple-service 'ziltis-home-files-service
                 home-files-service-type
                 `(#;(".gnupg/gpg-agent.conf" ,(local-file "gnupg/gpg-agent.conf"))))
 (simple-service 'ziltis-xdg-configuration-files-service
                 home-xdg-configuration-files-service-type
                 `(("sway/config" ,(local-file "./sway/sway"))
                   ("swaylock/config" ,(local-file "./swaylock/config"))
                   ("swayidle/config" ,(local-file "./swayidle/config"))
                   ("liquidpromptrc" ,(local-file "./liquidprompt/liquidpromptrc"))
                   ("xdg-desktop-portal-wlr/config" ,(local-file "./xdg-desktop-portal-wlr/config"))))
 (service home-syncthing-service-type)
 (service home-batsignal-service-type
          (home-batsignal-configuration
           (ignore-missing? #t)))
 (service home-mcron-service-type
          (home-mcron-configuration
           (jobs
            '())))
 (simple-service 'ziltis-packages
                 home-profile-service-type
                 (specifications->packages
                  (list "afew"
                        "bind:utils"
                        "bsd-games"
                        "bolt"
                        "browserpass-native"
                        "chicken"
                        "chicken-apropos"
                        "chicken-chicken-doc"
                        "chicken-srfi-18"
                        "curl"
                        "direnv"
                        "emacs-pgtk-xwidgets"
                        "emacs-desktop-environment"
                        "entr"
                        "eternalterminal"
                        "eudev"
                        "diff-so-fancy"
                        "file"
                        "firefox"
                        "flatpak@1.14.6"
                        "font-libertinus"
                        "font-nerdfont-monaspice"
                        "font-nerdfont-iosevka-term-slab"
                        "fuzzel"
                        "fzf"
                        "gammastep"
                        "gash"
                        "git"
                        "git:send-email"
                        "grim"
                        "guile"
                        "glibc-locales"
                        "heroic"
                        "hstr"
                        "hyprcursor"
                        "hyprpaper"
                        "hypridle"
                        "hyprlock"
                        "hyprland-xwayland-plugin-hyprsplit"
                        "icecat"
                        "icedove-wayland"
                        "isync"
                        "kdeconnect"
                        "kitty"
                        "ksshaskpass"
                        "kwayland-integration"
                        "lagrange"
                        "le-certs"
                        "ledger"
                        "libaacs"
                        "libbdplus"
                        "libbluray"
                        "liquidprompt"
                        "libportal"
                        "libsecret"
                        "make"
                        "muchsync"
                        "nix"
                        "nm-tray"
                        "nnn"
                        "nss-certs"
                        "notmuch"
                        "nwg-displays"
                        "offlineimap3"
                        "okular"
                        "openssh"
                        "password-store"
                        "pass-git-helper"
                        "pass-otp"
                        "pavucontrol"
                        "perl-mozilla-ca"
                        "pinentry-qt"
                        "pkg-config"
                        "plasma-wayland-protocols"
                        "process-compose"
                        "qt5ct"
                        "qtwayland@5.15.10"
                        "pv"
                        "rsync"
                        "rust"
                        "rust-cargo"
                        "sddm"
                        "senpai"
                        "sideload"
                        "signal-desktop"
                        "slurp"
                        "sshfs"
                        "steam"
                        "steam-devices-udev-rules"
                        "stow"
                        ;; "sponge" https://linux.die.net/man/1/sponge
                        "swappy"
                        "swayidle"
                        "swaylock-effects"
                        "swaynotificationcenter"
                        "telegram-desktop"
                        "tig"
                        "tmate"
                        "tmux"
                        "tree-sitter"
                        "ungoogled-chromium-wayland"
                        "unzip"
                        "virt-manager"
                        "visidata"
                        "vlc"
                        "waybar"
                        "wlogout"
                        "xdg-dbus-proxy"
                        "xdg-utils"

                        ;; "emacs-adaptive-wrap"
                        ;; "emacs-adoc-mode"
                        ;; "emacs-cape"
                        ;; "emacs-catppuccin-theme"
                        ;; "emacs-cider@1.13.0"
                        ;; ;;"emacs-code-review"
                        ;; "emacs-color-theme-modern"
                        ;; "emacs-consult-eglot"
                        ;; "emacs-consult-notes"
                        ;; "emacs-corfu"
                        ;; "emacs-dhall-mode"
                        ;; "emacs-editorconfig"
                        ;; "emacs-eglot"
                        ;; "emacs-el-patch"
                        ;; "emacs-embark-consult"
                        ;; "emacs-envrc"
                        ;; "emacs-evil"
                        ;; "emacs-evil-collection"
                        ;; "emacs-evil-easymotion"
                        ;; "emacs-evil-snipe"
                        ;; "emacs-forge"
                        ;; "emacs-geiser"
                        ;; "emacs-geiser-chicken"
                        ;; "emacs-geiser-guile"
                        ;; "emacs-git-gutter"
                        ;; "emacs-goto-chg"
                        ;; "emacs-guix"
                        ;; "emacs-highlight-parentheses"
                        ;; "emacs-keychain-environment"
                        ;; "emacs-ledger-mode"
                        ;; "emacs-ligature"
                        ;; "emacs-magit"
                        ;; "emacs-magit-todos"
                        ;; "emacs-marginalia"
                        ;; "emacs-moe-theme"
                        ;; "emacs-nerd-icons-completion"
                        ;; "emacs-nerd-icons-corfu"
                        ;; "emacs-orderless"
                        ;; "emacs-org"
                        ;; "emacs-org-modern"
                        ;; "emacs-org-rainbow-tags"
                        ;; "emacs-org-roam"
                        ;; "emacs-org-roam-ui"
                        ;; "emacs-paredit"
                        ;; "emacs-paren-face"
                        ;; "emacs-pass"
                        ;; "emacs-pinentry"
                        ;; "emacs-seq"
                        ;; "emacs-tempel"
                        ;; "emacs-transient"
                        ;; "emacs-tree-sitter"
                        ;; "emacs-unicode-fonts"
                        ;; "emacs-vertico"
                        ;; "emacs-visual-fill-column"
                        ;; "emacs-websocket"
                        ;; "emacs-wgrep"
                        ;; "emacs-which-key"
                        ;; "emacs-xref-union"
                        ;; "emacs-zig-mode"
                        ;; "emacs-corfu-terminal"
                        )))
 (service home-dbus-service-type)
 (service home-pipewire-service-type
          (home-pipewire-configuration
           (wireplumber wireplumber-minimal)))
 )
))
